@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.11
+#!/usr/local/bin/python3.13
 # Copyright (C) 2018 J.F.Dockes
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ import rclxslt
 import gzip
 from rclbasehandler import RclBaseHandler
 
+
 class XSLTExtractor(RclBaseHandler):
     def __init__(self, em, stylesheet, gzip=False):
         super(XSLTExtractor, self).__init__(em)
@@ -31,7 +32,7 @@ class XSLTExtractor(RclBaseHandler):
 
     def html_text(self, fn):
         if self.dogz:
-            data = gzip.open(fn, 'rb').read()
+            data = gzip.open(fn, "rb").read()
         else:
-            data = open(fn, 'rb').read()
+            data = open(fn, "rb").read()
         return rclxslt.apply_sheet_data(self.stylesheet, data)
