@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.13
 # Copyright (C) 2014 J.F.Dockes
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ import sys
 import rclexecm
 import rclgenxslt
 
-stylesheet_all = '''<?xml version="1.0"?>
+stylesheet_all = """<?xml version="1.0"?>
 <xsl:stylesheet version="1.0"
 		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 
@@ -54,9 +54,9 @@ stylesheet_all = '''<?xml version="1.0"?>
   </xsl:template>
 
 </xsl:stylesheet>
-'''
+"""
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     proto = rclexecm.RclExecM()
     extract = rclgenxslt.XSLTExtractor(proto, stylesheet_all)
     rclexecm.main(proto, extract)
